
n225
====


.. image:: https://img.shields.io/pypi/v/package_name.svg
   :target: https://pypi.python.org/pypi/n225
   :alt: Latest PyPI version


Get compositions and josuu.

Usage
-----

To update n225.csv, execute the command below.

.. code-block::

   python -m n225

Installation
------------

Requirements
^^^^^^^^^^^^

Compatibility
-------------

Licence
-------

Authors
-------

n225 was written by `fx-kirin <fx.kirin@gmail.com>`_.
